/* libnetk header */

/*
 * Copyright (C) 2001 Havoc Pennington
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef NETK_LIB_H
#define NETK_LIB_H

#include <libxfcegui4/netk-application.h>
#include <libxfcegui4/netk-screen.h>
#include <libxfcegui4/netk-util.h>
#include <libxfcegui4/netk-window.h>
#include <libxfcegui4/netk-window-action-menu.h>
#include <libxfcegui4/netk-workspace.h>
#include <libxfcegui4/netk-class-group.h>
#include <libxfcegui4/netk-trayicon.h>
#include <libxfcegui4/netk-enum-types.h>

#include <libxfcegui4/netk-pager.h>
#include <libxfcegui4/netk-tasklist.h>

#endif /* NETK_LIB_H */
